﻿#include <iostream>
#include "CheckerBoard.h"
#include "CheckersAI.h"
#include <io.h>
#include <fcntl.h>

int main()
{
    _setmode(_fileno(stdout), _O_U16TEXT);

    // Load the board from file
    CheckerBoard board = CheckerBoard::loadFromFile("board - Copy.checkers");

    // Print out the initial board setup
    board.print();

    // Separator line
    wcout << "\n\n-----------\n\n";

    CheckersAI whiteAI(true);
    CheckersAI blackAI(false);

    // Whites move first
    bool whiteTurn = true;

    // Run the game until one of the sides wins
    while (!board.isGameOver())
    {
        wcout << L"\n\n";

        // AI plays white
        if (whiteTurn)
        {
            wcout << "White: ";
            // Find the best move
            CheckerBoard bestMove = whiteAI.findBestMove(board, 7);

            // If no move is good enough, give up
            if (bestMove.lastMove == "NONE")
            {
                wcout << "White forfeit";
                return 0;
            }

            // Apply the best move to the board
            board.applyMove(bestMove);
        }
        // Раскомментировать для игры ИИ против ИИ
        /*else {
            wcout << "Black: ";
            // Find the best move
            CheckerBoard bestMove = blackAI.findBestMove(board, 7);

            // If no move is good enough, give up
            if (bestMove.lastMove == "NONE")
            {
                wcout << "Black forfeit";
                return 0;
            }

            // Apply the best move to the board
            board.applyMove(bestMove);
        }*/
        // Раскомментировать для игры Человек против ИИ
        else
        {
            while (true)
            {
                // Read initial checker position
                wcout << "Checker position: ";
                std::string inp;
                cin >> inp;
                CheckerPosition pos(inp);

                // Read desired new checker position
                wcout << "Move to: ";
                std::string inp2;
                cin >> inp2;
                CheckerPosition newPos(inp2);

                // Check if the move is valid
                if (!board.isValidMove(pos, newPos, board.getCheckerAt(pos)) /* && !board.isValidCapture(pos, newPos, CheckerPosition(cx, cy), board.getCheckerAt(pos))*/)
                {
                    wcout << "Wrong move" << endl;
                    // If the move is not valid, ask again
                    continue;
                }

                // If the move is valid, apply it
                board.moveChecker(pos, newPos);

                // Exit the user-interaction loop
                break;
            }
        }
        // Change turns
        whiteTurn = !whiteTurn;

        // Print out the board
        board.print();
    }

    wcout << L"Game over!\n";
}